%% Die Funktion cluster_by_isa klassifiziert dynamische Daten anhand von NoOfClus
%% Eigenvektoren (Evs) der Uebergangsmatrix. NoOfClus (default=2) legt dabei
%% fest, wieviele Cluster es geben soll. Die verwendete Methode: Inner Simplex 
%% Algorithmus. 

%% Restriktion: Evs muss mindestens NoOfClus Eigenvektoren beinhalten.

%% Beispiele:

%% cluster_by_isa(Evs,NoOfClus)
%% --> Ausgabe: Gibt einen Vektor cF aus, der zu jeder Zeile der Uebergangsmatrix
%%              eine Clusterzuordnung vornimmt.

%% [cF, indic, Chi, RotMat] = cluster_by_isa (Evs, NoOfClus)
%% --> Ausgabe:  cF ist wieder der Zuordnungsvektor. indic liefert den Indikator
%%               fuer die Eindeutigkeit der Zuordnung. Dieser Zahlenwert sollte
%%               ungefaehr Null sein. Chi gibt fuer jeden Cluster einen Vektor von 
%%               Zugehoerigkeitsgraden im Sinne der Fuzzy-Theorie an. 
%%               RotMat ist diejenige lineare Transformation, die Evs in Chi
%%               ueberfuehrt, sie sollte eine wohlkonditionierte Matrix sein.
%%               ind gibt die Eckenindizes aus

function [Chi, RotMat] = cluster_by_isa (Evs, NoOfClus)
% default-Zuweisung 2 Cluster
if nargin < 2
    NoOfClus =2;
end
% Sonderfaelle abfangen
if NoOfClus <2
    Chi=ones(size(Evs,1),1);
    indic=0;
    RotMat=1/Evs(1,1);
    cF=ones(size(Evs,1),1);
elseif (NoOfClus >= size(Evs,1) & size(Evs,2)==size(Evs,1))
    Chi=eye(size(Evs,1));
    indic=0;
    RotMat=inv(Evs);
    cF=[1:size(Evs,1)];
else
    % Genuegend Eigenvektoren angegeben?
    NoOfClus=round(NoOfClus);
    if NoOfClus> size(Evs,2)
        NoOfClus=size(Evs,2);
    end
    % Eigentlicher ISA-Algorithmus
    C=Evs(:, 1:NoOfClus);
    OrthoSys=C;
    maxdist=0.0;
    % Ersten beiden Repraesentanten mit maximalen Abstand
    for i=1:size(Evs,1)        
       if norm(C(i,:)) > maxdist
                maxdist = norm(C(i,:));
                ind(1)=i;
       end
    end
    for i=1:size(Evs,1)
        OrthoSys(i,:)=OrthoSys(i,:)-C(ind(1),:);
    end;
    OrthoSys;
    
    % Weitere Repraesentatnten ueber Gram-Schmidt Orthogonalisierung
    for k = 2:NoOfClus
        maxdist=0.0;
        temp=OrthoSys(ind(k-1),:);
        for i=1:size(Evs,1)
            OrthoSys(i,:)=OrthoSys(i,:)-(temp*transpose(OrthoSys(i,:)))*temp;
            distt=norm(OrthoSys(i,:));
            if distt > maxdist
                maxdist = distt;
                ind(k)=i;
            end
        end
            ind; 
            maxdist;
        OrthoSys=OrthoSys./norm(OrthoSys(ind(k),:));
    end
    % Lineare Transformation der Eigenvektoren
    RotMat= inv(C(ind,:));
    Chi=C*RotMat;
    % Bestimmung des Indikators
    indic=min(min(Chi));
    % Defuzzifizierung der Zugehoerigkeitsfunktionen
    [minVal cF]=max(transpose(Chi));
end