%% Initializations
clear

% space discretization  
N = 20;

% time discretization
M = 10;

% Schroedinger timestep
mu = -4.0086e-002;  

% number of clusters
cl_rev = 6; 
 
%% Main routine

%%FAD
load N_el_val_fad.mat

% dimensions
s1=size(N_el,1)/N;
dens=zeros(s1,M+1);

% number of time intervals
ts=length(t)/4;
time_frames_intv=ts/M;
time_intv=t(ts)/M;

% sum up electron density for discretization
for j=1:(M+1)    
    for i=1:s1
        dens(i,j)=sum(N_el(((i-1)*N+1):(i*N),(j-1)*time_frames_intv+1));
    end
end
dens=dens+0.00001;
dens=dens*diag(1./sum(dens));


%% time propagation (Transition count)

% initialize mu
Q_start=zeros(s1,s1);
Q_start(s1,s1-1)=sqrt_f(dens(s1-1,1),dens(s1,1));
Q_start(s1,1)=sqrt_f(dens(1,1),dens(s1,1));
Q_start(1,s1)=sqrt_f(dens(s1,1),dens(1,1));
Q_start(1,2)=sqrt_f(dens(2,1),dens(1,1));
for i=2:(s1-1)
    Q_start(i,i+1)=sqrt_f(dens(i+1,1),dens(i,1));
    Q_start(i,i-1)=sqrt_f(dens(i-1,1),dens(i,1));
end
Q_start=Q_start-diag(sum(Q_start,2));
v=eigs(Q_start,3,'lr');
mu = mu/v(2);

T=[];
errf=[];
gamma=0.5;
for j=1:M
      t_start = (j-1)*time_intv;
      t_end   =  j*time_intv;
      
      % Q step-by-step
      Q_end=zeros(s1,s1);
      Q_end(s1,s1-1)=sqrt_f(dens(s1-1,j+1),dens(s1,j+1));
      Q_end(s1,1)=sqrt_f(dens(1,j+1),dens(s1,j+1));
      Q_end(1,s1)=sqrt_f(dens(s1,j+1),dens(1,j+1));
      Q_end(1,2)=sqrt_f(dens(2,j+1),dens(1,j+1));
      for i=2:(s1-1)
          Q_end(i,i+1)=sqrt_f(dens(i+1,j+1),dens(i,j+1));
          Q_end(i,i-1)=sqrt_f(dens(i-1,j+1),dens(i,j+1));
      end
      Q_end=mu*(Q_end-diag(sum(Q_end,2)));
      
      Pab = expm((t_end-t_start)*Q_end);

      % count brutto transitions
      Tab = diag(dens(:,j))*Pab;
            
      % count netto transitions
      Nab = Tab-Tab';
      Cab = ((Nab > 0)*1).*Nab;
      Dab = ((Nab < 0)*1).*Tab;
      Tab = Cab + diag(diag(Tab)) + diag(sum(Dab,1)) + diag(sum(Dab,2));
            
      % Propagation error
      errf = [errf, norm(sum(Tab,1)'-dens(:,j+1))];
      
      % construct total netto transition count matrix
      if (j==1)
        T=[T;[Tab',zeros(s1,(M-1)*s1)]];
      else
        T=[T;[zeros(s1,(j-2)*s1),gamma*Tab',(1-gamma)*Tab',zeros(s1,(M-j)*s1)]];
      end
end
% T according to archive paper Fackeldey et al. from 2017
T=T'; 
T_plus=[zeros(M*s1,s1), T(:,1:end-s1)]; T=T+T_plus;

 
% conditional transition probabilities
pi_dens=sum(T,2);
P=diag(1./sum(T,2))*T;

% Clustering for non-reversible case via Schur
Pd=diag(sqrt(pi_dens))*P*diag(1./sqrt(pi_dens));
[u, v]=schur(Pd);
[u, v]=SRSchur(u, v, 1, cl_rev);
u=diag(1./sqrt(pi_dens))*u;
chi_rev=cluster_by_isa(u, cl_rev);

% plot clustering
figure(1);
hold off;
plot(chi_rev(1:s1,:));
hold on;
for i=1:M-1
    plot(chi_rev((i*s1+1):((i+1)*s1),:));
end
hold off;
